#ifndef NEWPROGRAM_H
#define NEWPROGRAM_H

#include <QtGui>
#include "sql.h"

class NewProgram : public QMainWindow
{
    Q_OBJECT
public:
    explicit NewProgram(QWidget *parent = 0);
    void load(QString n);

private:
    SQL *sql;

    void load();

    QVBoxLayout *vLayout;
    QListView *lstExercises;
    QStandardItemModel *model;
    QLineEdit *txtName;
    QPushButton *btnSave;

    QString name;

private slots:
    void saveExercise();

signals:
    void closed();

};

#endif // NEWPROGRAM_H
